Class: Spree::StaticContentController

Inherits:
StoreController
  • Object
show all
Defined in:
lib/controllers/frontend/spree/static_content_controller.rb

Instance Method Summary collapse

Instance Method Details

#showObject



8
9
10
11
12
13
14
15
16
# File 'lib/controllers/frontend/spree/static_content_controller.rb', line 8

def show
  @page = Spree::Page.by_store(current_store).visible.find_by!(slug: request.path_info)

  # Assign static_content to let solidus recognize it as the current
  # controller resource, this is used by meta tags and in other places.
  @static_content = @page

  @taxonomies = Spree::Taxonomy.includes(root: :children)
end